@@ -1,4 +1,5 @@
 <?php
+define('WP_CACHE', true); // WP-Optimize Cache
 /**
  * The base configuration for WordPress
  *
@@ -11,33 +12,25 @@
  * * Database settings
  * * Secret keys
  * * Database table prefix
- * * Localized language
  * * ABSPATH
  *
- * @link https://wordpress.org/support/article/editing-wp-config-php/
+ * @link https://wordpress.org/documentation/article/editing-wp-config-php/
  *
  * @package WordPress
  */
-
 // ** Database settings - You can get this info from your web host ** //
 /** The name of the database for WordPress */
-define( 'DB_NAME', 'techfrea_wp_xdb8z' );
-
+define( 'DB_NAME', 'vrclvilv_wp665' );
 /** Database username */
-define( 'DB_USER', 'techfrea_wp_l1ggo' );
-
+define( 'DB_USER', 'vrclvilv_wp665' );
 /** Database password */
-define( 'DB_PASSWORD', 'DVZa!*l5L8fI~^9v' );
-
+define( 'DB_PASSWORD', 'St]p)gDP]2](93nx' );
 /** Database hostname */
-define( 'DB_HOST', 'localhost:3306' );
-
+define( 'DB_HOST', 'localhost' );
 /** Database charset to use in creating database tables. */
 define( 'DB_CHARSET', 'utf8' );
-
 /** The database collate type. Don't change this if in doubt. */
 define( 'DB_COLLATE', '' );
-
 /**#@+
  * Authentication unique keys and salts.
  *
@@ -49,30 +42,22 @@ define( 'DB_COLLATE', '' );
  *
  * @since 2.6.0
  */
-define('AUTH_KEY', 's&&d5G+M(7-I7Ff;[xn#57/JeJ%K1T&vm&(-eNr4]QtxeTI:f&#!0m_1sDs2o&vB');
-define('SECURE_AUTH_KEY', 'n+6nN4h&03E3MO7aj)vzs1nh+b|6@9Tj4Nd6[34+O8&/8g&BB44&7#-4Iu![83#1');
-define('LOGGED_IN_KEY', '3!fp*+E/kt%9B@KsN3:nEE/y]j@rJ-q8oe8;1jy&MENCs7v!fnIav]tF-90XXN-g');
-define('NONCE_KEY', 'v-g4S|V45~44/|[6PK26zqIu[7]~2C137|bd|rMIdJF8ekaK8fmIiCLju_[)k!%d');
-define('AUTH_SALT', '3s&-@A-9;6G8Qf!x5Ky/]R1-9EB1_4&2qy+MgPTWN!z58w9(ReRp7*7j/g[ch4(L');
-define('SECURE_AUTH_SALT', 'Hr~-r)1GB|3Mo!:*ftd8![v(|qL+#4!61zSm36-@!Na7(tP85J4t65H35:QxB8&9');
-define('LOGGED_IN_SALT', ']9J+k5_#&NS16t8tq6+v5:2Ob1CF][uk885:8+7tl1[~mi)MDfDq4d+/5&H8Aqu9');
-define('NONCE_SALT', 'O/;0-wI]H86DGMBR24+U[X@_un*;cv120;*CVr5R5K054h7nkxh!7;2BO*4sF9+2');
-
-
+define( 'AUTH_KEY',         'aendaifqsbkitairb2tzczz8i4oadxqhkduzv3aayozrwy7apuembwlozc5pjxuy' );
+define( 'SECURE_AUTH_KEY',  'lps9zfygtpwyozm4mxlrutlg7yt1whhq6nqfqine0fterp0scnsgk4vskcngxez9' );
+define( 'LOGGED_IN_KEY',    'udkuxcxuewzcncotif7t3ylz2fswnahzocdlfuukwthmec45hq8rhlk8ebgghepv' );
+define( 'NONCE_KEY',        '5spb2pvqhlavaaczdcaul95mrnqpwxnmb9qwnpbftj1vep5kcmasdgugktgsqusz' );
+define( 'AUTH_SALT',        'ldwopgzhbvvsctdda8fvco7edbi5537rg00jgsvewnvzumyfoxpixfahhfs1zq1d' );
+define( 'SECURE_AUTH_SALT', 'c9nksz72ymdwx33fmchx86grkzrylnggtxrzgignqndzvlvcrzcvu6hnqy2h6jjl' );
+define( 'LOGGED_IN_SALT',   'sm3oos2ux0ztohtnnjdruds2dgcxqdfsvfhpxh4vdqrun9xkqh2see2yfeflncsb' );
+define( 'NONCE_SALT',       '8prgvh1fgn8sixuewpfe4feczedna4vfrmccm0thshzjnuikabdg4irhnk0urfjf' );
 /**#@-*/
-
 /**
  * WordPress database table prefix.
  *
  * You can have multiple installations in one database if you give each
  * a unique prefix. Only numbers, letters, and underscores please!
  */
-$table_prefix = 'D8WJyrYW_';
-
-
-/* Add any custom values between this line and the "stop editing" line. */
-
-define('WP_ALLOW_MULTISITE', true);
+$table_prefix = 'wpxl_';
 /**
  * For developers: WordPress debugging mode.
  *
@@ -83,18 +68,14 @@ define('WP_ALLOW_MULTISITE', true);
  * For information on other constants that can be used for debugging,
  * visit the documentation.
  *
- * @link https://wordpress.org/support/article/debugging-in-wordpress/
+ * @link https://wordpress.org/documentation/article/debugging-in-wordpress/
  */
-if ( ! defined( 'WP_DEBUG' ) ) {
-	define( 'WP_DEBUG', false );
-}
-
+define( 'WP_DEBUG', false );
+/* Add any custom values between this line and the "stop editing" line. */
 /* That's all, stop editing! Happy publishing. */
-
 /** Absolute path to the WordPress directory. */
 if ( ! defined( 'ABSPATH' ) ) {
 	define( 'ABSPATH', __DIR__ . '/' );
 }
-
 /** Sets up WordPress vars and included files. */
-require_once ABSPATH . 'wp-settings.php';
+require_once ABSPATH . 'wp-settings.php';
\ No newline at end of file
